# Changelog

<!-- <START NEW CHANGELOG ENTRY> -->

## 0.2.1

([Full Changelog](https://github.com/jupyterlite/xeus-sqlite-kernel/compare/v0.2.0...b68956a2a702a8d737e80b8d0f10d0af15abb50e))

### Merged PRs

- Update xeus [#11](https://github.com/jupyterlite/xeus-sqlite-kernel/pull/11) ([@martinRenou](https://github.com/martinRenou))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/jupyterlite/xeus-sqlite-kernel/graphs/contributors?from=2022-03-17&to=2022-05-19&type=c))

[@martinRenou](https://github.com/search?q=repo%3Ajupyterlite%2Fxeus-sqlite-kernel+involves%3AmartinRenou+updated%3A2022-03-17..2022-05-19&type=Issues)

<!-- <END NEW CHANGELOG ENTRY> -->

## 0.2.0

([Full Changelog](https://github.com/jupyterlite/xeus-sqlite-kernel/compare/v0.1.2...e71db9a190aabefb56c73b76744373f3ef4777fb))

### Merged PRs

- Update xeus to 2.4 [#8](https://github.com/jupyterlite/xeus-sqlite-kernel/pull/8) ([@SylvainCorlay](https://github.com/SylvainCorlay))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/jupyterlite/xeus-sqlite-kernel/graphs/contributors?from=2022-02-01&to=2022-03-17&type=c))

[@SylvainCorlay](https://github.com/search?q=repo%3Ajupyterlite%2Fxeus-sqlite-kernel+involves%3ASylvainCorlay+updated%3A2022-02-01..2022-03-17&type=Issues)

## 0.1.2

([Full Changelog](https://github.com/jupyterlite/xeus-sqlite-kernel/compare/v0.1.1...8ee6f9258ad24d814c9428d60d5e70482768607e))

### Maintenance and upkeep improvements

- Minor fixes [#4](https://github.com/jupyterlite/xeus-sqlite-kernel/pull/4) ([@jtpio](https://github.com/jtpio))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/jupyterlite/xeus-sqlite-kernel/graphs/contributors?from=2022-01-31&to=2022-02-01&type=c))

[@jtpio](https://github.com/search?q=repo%3Ajupyterlite%2Fxeus-sqlite-kernel+involves%3Ajtpio+updated%3A2022-01-31..2022-02-01&type=Issues)

## 0.1.1

([Full Changelog](https://github.com/jupyterlite/xeus-sqlite-kernel/compare/first-commit...22f308f2c283513bd6d79f75f9f2de632f980876))

### Maintenance and upkeep improvements

- change repo owner from DerThorsten to jupyterlite [#1](https://github.com/jupyterlite/xeus-sqlite-kernel/pull/1) ([@DerThorsten](https://github.com/DerThorsten))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/jupyterlite/xeus-sqlite-kernel/graphs/contributors?from=2022-01-31&to=2022-01-31&type=c))

[@DerThorsten](https://github.com/search?q=repo%3Ajupyterlite%2Fxeus-sqlite-kernel+involves%3ADerThorsten+updated%3A2022-01-31..2022-01-31&type=Issues) | [@jtpio](https://github.com/search?q=repo%3Ajupyterlite%2Fxeus-sqlite-kernel+involves%3Ajtpio+updated%3A2022-01-31..2022-01-31&type=Issues)
